#!/usr/bin/env python3
# -*- coding: utf-8 -*-

import redis
from liquiclient.config import get_property


# 获取mysql实例
def get_redis_client():

    host = get_property("redis.host")
    port = get_property("redis.port")
    username = get_property("redis.username")
    password = get_property("redis.password")

    client = redis.Redis(host=host, port=port, username=username, password=password, decode_responses=True)

    return client



#!/usr/local/bin/python3
# coding: utf8
import sys
from jproperties import Properties
import os

config = Properties()


# 获取配置信息
def get_config(filepath):
    with open(filepath, 'rb') as prop:
        config.load(prop)


# 默认找项目路径的文件
def auto_config():
    # 获取当前工作目录
    current_working_directory = os.getcwd()

    # 获取父级目录
    parent_directory = os.path.dirname(current_working_directory)

    # 在父级目录中拼接给定的文件名
    file_path = os.path.join(parent_directory, "liquibase.properties")
    with open(file_path, 'rb') as prop:
        config.load(prop)


# 获取配置的某一个key
def get_property(name):
    if name == "":
        return config
    return config[name].data


# 获取租户id
def get_tenant():
    return get_property("parameter.tenant")


# 获取空间id
def get_biz():
    return get_property("parameter.biz")


# 获取根据租户分库分表
def get_tenant_shard(key):
    kfuin = get_property("parameter.tenant")
    return key + "_" + kfuin


auto_config()



#!/usr/bin/env python3
# -*- coding: utf-8 -*-

from liquiclient.config import get_property
from urllib.parse import urlparse
from urllib.parse import parse_qs
import mysql.connector


# 获取mysql实例
def get_mysql_client():
    # 由于默认liquibase是jdbc的，这里解析对应的ip port
    params = parse_jdbc_dsn(get_property("url"))
    client = mysql.connector.connect(**params)
    client.autocommit = True

    return client.cursor()


def parse_jdbc_dsn(dsn):
    url_str = dsn.lstrip("jdbc:mysql://")
    # 如果URL没有scheme，为其添加默认的http或https
    if not url_str.startswith(('http://', 'https://')):
        url_str = 'http://' + url_str

    print(url_str)
    # 当成url解析
    url_obj = urlparse(url_str)
    query_params = parse_qs(url_obj.query)
    print(query_params)
    # 获取账号密码
    username = get_property("username")
    password = get_property("password")

    config = {
        "host": url_obj.hostname,
        "port": url_obj.port,
        "database": url_obj.path.lstrip("/"),
        "user": username,
        "password": password,
        "charset": query_params['characterEncoding'][0],
    }
    print(config)

    return config
